Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms
Imports System.IO
Imports ColorCode
Imports SelectPdf

Namespace SelectPdf.Samples
    Partial Public Class PdfViewerPreferences
        Inherits Form

        Private Sub BtnCreatePdf_Click(sender As Object, e As EventArgs) _
            Handles BtnCreatePdf.Click
            Cursor = Cursors.WaitCursor
            Dim file As String = "Document.pdf"

            Try
                ' create a new pdf document
                Dim doc As New PdfDocument()

                ' add a new page to the document
                Dim page As PdfPage = doc.AddPage()

                ' create a new pdf font
                Dim font As PdfFont = doc.AddFont(PdfStandardFont.Helvetica)
                font.Size = 20

                ' create a new text element and add it to the page
                Dim text As New PdfTextElement(50, 50, _
                        "Select.Pdf for .NET - Pdf Viewer Preferences Sample", font)
                page.Add(text)

                ' set the pdf viewer preferences
                doc.ViewerPreferences.CenterWindow = True
                doc.ViewerPreferences.DisplayDocTitle = True
                doc.ViewerPreferences.FitWindow = True
                doc.ViewerPreferences.HideMenuBar = True
                doc.ViewerPreferences.HideToolbar = True
                doc.ViewerPreferences.HideWindowUI = False

                doc.ViewerPreferences.NonFullScreenPageMode = _
                    PdfViewerFullScreenExitMode.UseNone
                doc.ViewerPreferences.PageLayout = PdfViewerPageLayout.SinglePage
                doc.ViewerPreferences.PageMode = PdfViewerPageMode.UseNone

                ' save pdf document
                doc.Save(file)

                ' close pdf document
                doc.Close()
            Catch ex As Exception
                MessageBox.Show([String].Format("Error: {0}", ex.Message), "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
                Return
            Finally
                Cursor = Cursors.Arrow
            End Try

            ' open generated pdf
            Try
                System.Diagnostics.Process.Start(file)
            Catch
                MessageBox.Show("Could not open generated pdf document", "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
            End Try
        End Sub

        Public Sub New()
            InitializeComponent()

            Try
                ' display highlighted sample code
                Dim code As String = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory + _
                                                      "/../../" + "PdfViewerPreferences.vb")
                WBSampleCode.DocumentText = New CodeColorizer().Colorize(code, Languages.VbDotNet)
            Catch
                WBSampleCode.DocumentText = "Sample code not available"
            End Try
        End Sub

    End Class
End Namespace
